@@ -1,10 +1,13 @@
 import re
 import subprocess
 
+from pathlib import Path
+
 from django import template
 from django.conf import settings
 from django.utils.safestring import mark_safe
 from django.core.cache import cache
+from django.templatetags.static import static
 
 
 class TailwindCSS:
@@ -12,6 +15,10 @@ class TailwindCSS:
         self._css_rule = re.compile(r"/.*}")
         self._cli_file = settings.TAILWINDCSS_CLI_FILE
         self._config_file = settings.TAILWINDCSS_CONFIG_FILE
+        self._output_file = settings.TAILWINDCSS_OUTPUT_FILE
+
+        self._output_filepath = Path(settings.STATIC_ROOT) / settings.TAILWINDCSS_OUTPUT_FILE
+        self._is_output_filepath = self._output_filepath.is_file()
 
     @property
     def css(self):
@@ -21,6 +28,12 @@ class TailwindCSS:
         else:
             self.refresh()
             return cache.get('tailwindcss')
+    
+    @property
+    def css_url(self):
+        if self._is_output_filepath:
+            return static(self._output_file)
+        return ''
 
     def refresh(self):
         task = subprocess.run(
@@ -39,6 +52,9 @@ register = template.Library()
 
 
 @register.simple_tag
-def tailwindcss():
-    css = mark_safe("<style>{}</style>".format(tailwind.css))
-    return css
+def tailwindcss(raw=False):
+    if raw:
+        return mark_safe(tailwind.css)
+    if tailwind.css_url:
+        return mark_safe('<link rel="stylesheet" type="text/css" href="{}">'.format(tailwind.css_url))
+    return mark_safe("<style>{}</style>".format(tailwind.css))
